import xml.etree.ElementTree as ET

class Upd970():

    def __init__(self,head, buyer,seller,table, docs) -> None:
        
        self.head = head
        self.buyer = buyer
        self.seller = seller
        self.table = table
        self.docs = docs

        self.upd_date_russian= head["upd_date"].strftime("%d.%m.%Y")
        self.upd_date_yyyymmdd= head["upd_date"].strftime("%Y%m%d")
        
    def org_info(self,parent,infodict):
        
        sv = ET.SubElement(parent,"ИдСв")
        
        if len(infodict["ИНН"]) == 10:
            svul =  ET.SubElement(sv,"СвЮЛУч", {
                "НаимОрг":infodict["НаимОрг"],
                "ИННЮЛ":infodict["ИНН"],
                "КПП":infodict ["КПП"]
            })
        elif len(infodict["ИНН"]) ==12:
            svul =  ET.SubElement(sv,"СвИП", {
                "ИННФЛ":infodict["ИНН"]
            })

            fio = ET.SubElement (svul,"ФИО", {
                "Фамилия": infodict["НаимОрг"].split()[1],
                "Имя": infodict["НаимОрг"].split()[2],
                "Отчество": infodict["НаимОрг"].split()[3]
            })
            
        adr0 = ET.SubElement(parent,"Адрес")
        
        fields = ["КодРегион","НаимРегион","Район","Город","Индекс","Улица","Дом","Корпус","Кварт","НаселПункт"]
        addr_fields={}
        for f in fields:
            if infodict[f]:
                addr_fields[f]=infodict[f]

        adr = ET.SubElement(adr0,"АдрРФ",addr_fields)

    def tovar_info(self,parent):
        for tov in self.table:
            sv = ET.SubElement(parent,"СведТов",{
                "СтТовУчНал":tov["Стоимость"],
                "СтТовБезНДС":tov["СтоимостьБезНДС"],
                "ЦенаТов":tov["Цена"],
                "КолТов":tov["Кол"],
                "НаимЕдИзм":tov["НаимЕдИзм"],
                "ОКЕИ_Тов":tov["ОКЕИ"],
                "НаимТов":tov["Товар"],
                "НалСт":"20%",
                "НомСтр":tov["НомСтр"]
            })
            dop = ET.SubElement(sv,"ДопСведТов")
            sumnal = ET.SubElement(dop,"СумНалВосст")
            beznds  = ET.SubElement(sumnal,"БезНДС")
            beznds.text = "без НДС"

            akciz = ET.SubElement(sv,"Акциз")
            bezakciz  = ET.SubElement(akciz,"БезАкциз")
            bezakciz.text = "без акциза"

            sumnal_1 = ET.SubElement(sv,"СумНал")
            sumnal_2  = ET.SubElement(sumnal_1,"СумНал")
            sumnal_2.text = tov["СуммаНалога"]

        totalsum = ET.SubElement(parent,"ВсегоОпл",{"КолНеттоВс":"0", "СтТовУчНалВсего":self.head["СтоимВсего"], "СтТовБезНДСВсего":self.head["СтоимБезНДСВсего"]})
        totalsumnal = ET.SubElement(totalsum,"СумНалВсего")
        totalsumnal_2 = ET.SubElement(totalsumnal,"СумНал")
        totalsumnal_2.text = self.head["СумНал"]

    def create_xml(self, path):
        
        h1 = self.buyer["guid"]
        h2 = self.seller["guid"]
        h3 = self.upd_date_yyyymmdd
        h4 = self.head["guid_doc"]
    
        filename= f"ON_NSCHFDOPPR_{h1}_{h2}_{h3}_{h4}_0_0_0_0_0_00"
        root = ET.Element("Файл", {"ИдФайл": filename, "ВерсФорм": "5.03","ВерсПрог": "Diadoc 1.0"})
        
        document = ET.SubElement(root,"Документ", {
            "ВремИнфПр": "12.00.01",
            "ДатаИнфПр": self.upd_date_russian,
            "КНД": "1115131",
            "НаимДокОпр": "Универсальный передаточный документ",
            "НаимЭконСубСост": self.seller["НаимОрг"],
            "ПоФактХЖ": "Документ об отгрузке товаров (выполнении работ), передаче имущественных прав (документ об оказании услуг)",    
            "Функция": "СЧФДОП"
        })
        
        schf = ET.SubElement(document,"СвСчФакт", {"ДатаДок": self.upd_date_russian, "НомерДок": self.head["upd_number"]})
        
        seller = ET.SubElement(schf,"СвПрод")
        seller_info = self.org_info(seller,self.seller)
        
              
        gruzot = ET.SubElement(schf,"ГрузОт")
        gruzot_info = ET.SubElement(gruzot,"ОнЖе")
        gruzot_info.text= "он же"
        
        gruzpol = ET.SubElement(schf,"ГрузПолуч")
        gruzpol_info = self.org_info(gruzpol,self.buyer)
        
        if self.head["ПП_Дата"] and self.head["ПП_Номер"]:
            pp_data = self.head["ПП_Дата"].strftime("%d.%m.%Y")
            pp_num = str(self.head["ПП_Номер"])
            pp = ET.SubElement(schf,"СвПРД",{"ДатаПРД":pp_data, "НомерПРД":pp_num})
        

        punkt5 = ET.SubElement(schf,"ДокПодтвОтгрНом",{
            "РеквДатаДок":self.upd_date_russian,
            "РеквНомерДок":self.head["upd_number"],
            "РеквНаимДок":"Универсальный передаточный документ"
        })
        
        buyer = ET.SubElement(schf,"СвПокуп")
        gruzpol_info = self.org_info(buyer,self.buyer)

        currency = ET.SubElement(schf,"ДенИзм",{"НаимОКВ":"Российский рубль","КодОКВ":"643"})

        
        
        main_table = ET.SubElement(document,"ТаблСчФакт")
        tovar_table = self.tovar_info(main_table)

        osn_pered = ET.SubElement(document,"СвПродПер")
        pered = ET.SubElement(osn_pered,"СвПер",{"ДатаПер":self.upd_date_russian,"СодОпер":"Товары переданы"})
        
        for osn in self.docs:
            ET.SubElement(pered,"ОснПер",osn)
        
        signer = ET.SubElement(document, "Подписант",{"СпосПодтПолном":"1"})
        #employee = ET.SubElement(signer, "ЮЛ", {"Должн": "Директор","ИННЮЛ": "","НаимОрг": "ТД Стимлайн, ООО"})
        ET.SubElement(signer,"ФИО",{"Имя":"Олег","Отчество":"Анатольевич","Фамилия":"Трифонов"})
        
        
        #for a in root.iter():
        #    print(a)

        tree = ET.ElementTree(root)
               
        tree.write(path +'\\'+filename+'.xml', encoding="windows-1251", xml_declaration=True)


if __name__ == "__main__":
    pass

